@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2024-08-22
+# Release 2024-10-20
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.7.2
+MAKERESOLVEDEB_VERSION=1.7.3
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -398,7 +398,13 @@ process_19() {
     if [[ -e "${UNPACK_DIR}"/share/remote-monitor-log-conf.xml ]]; then
 	copy_object "${UNPACK_DIR}"/share/remote-monitor-log-conf.xml "${RESOLVE_BASE_DIR}"/share/
     fi
-    
+
+    # Disable libs
+    for lib in "libgio-2.0" "libglib-2.0" "libgobject-2.0" "libgmodule-2.0"; do
+	mkdir -p "${RESOLVE_BASE_DIR}"/libs/disabled
+	mv "${RESOLVE_BASE_DIR}"/libs/"${lib}"* "${RESOLVE_BASE_DIR}"/libs/disabled/
+    done
+
     # Extract panel API library
     create_directory "${DEB_DIR}"/usr/lib
     extract_tgz "${UNPACK_DIR}"/share/panels/dvpanel-framework-linux-x86_64.tgz "${DEB_DIR}"/usr/lib libDaVinciPanelAPI.so
